# boilerdaq

[![All Contributors](https://img.shields.io/github/all-contributors/softboiler/boilerdaq?color=ee8449&style=flat-square)](#contributors)

Data acquisition for a nucleate pool boiling experimental apparatus.

## Project information

- [Changes](<https://softboiler.github.io/boilerdaq/changelog.html>)
- [Docs](<https://softboiler.github.io/boilerdaq>)
- [Contributing](<https://softboiler.github.io/boilerdaq/contributing.html>)

## Contributors

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tbody>
    <tr>
      <td align="center" valign="top" width="14.28%"><a href="https://www.blakenaccarato.com/"><img src="https://avatars.githubusercontent.com/u/20692450?v=4?s=100" width="100px;" alt="Blake Naccarato"/><br /><sub><b>Blake Naccarato</b></sub></a><br /><a href="#code-blakeNaccarato" title="Code">💻</a></td>
    </tr>
  </tbody>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->
